# Sudoku-SAT-compiler (ssc)

Describe generalized Sudokus through simple equations. Compile programs to SAT and solve them with `limboole`.

See `examples/` for example programs.

See `ssc --help` for all options.

Required Python version: `>= 3.9`

## Recommended Installation Instructions

- install `limboole`, either through your system's package manager or manually
- install `ssc`:
	- `python -m venv .ssc`
	- `. ./ssc/bin/activate`
	- `pip install ssc-compiler`

## Manual Installation Instructions

- install `limboole`, either through your system's package manager or manually
	- install `ssc`:
	- `git clone git@github.com:charludo/ssc.git`
	- `python -m venv .ssc`
	- `. .ssc/bin/activate`
	- `cd ssc`
	- `pip install -e .`
